/*
 * Copyright 2011 livedoor Co.,Ltd.
 *
 * Licensed under the Apache License, Version 2.0.
 *
 */

#import "AuthViewController.h"
#import "AppDelegate.h"
#import "JSONKit.h"
#import "LoctouchAPIConnection.h"

@interface AuthViewController()

- (NSString *)urlencode:(NSString *)string;
- (void)loadStatus;

@end

@implementation AuthViewController

- (IBAction)requestAccessToken:(id)sender {

    NSAssert([LOCTOUCH_CLIENT_ID length] > 0, @"Set LOCTOUCH_CLIENT_ID at AuthViewController.h.");

    NSString* urlScheme = [(AppDelegate *)[[UIApplication sharedApplication] delegate] urlScheme];
    NSString* urlString = [NSString stringWithFormat:@"https://tou.ch/oauth2/authenticate?client_id=%@&response_type=token&redirect_uri=%@%@", LOCTOUCH_CLIENT_ID, urlScheme, [self urlencode:@"://auth"]];    
    
    [[UIApplication sharedApplication] openURL:[NSURL URLWithString:urlString]];
}

- (void)saveAccessToken:(NSURL*)url {
    
    NSArray *keyValue = [[url fragment] componentsSeparatedByString:@"="];
    NSString *accessToken = [keyValue objectAtIndex:1];

    [[NSUserDefaults standardUserDefaults] setObject:accessToken forKey:@"loctouch_access_token"];
    
    [self loadStatus];
}

- (void)loadStatus {
    
    LoctouchAPIConnection* connection = [[[LoctouchAPIConnection alloc] init] autorelease];
    connection.urlString = @"https://api.loctouch.com/v1/users/@self";
    
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(didLoadStatus:) name:LOCTOUCH_API_CONNECTION_DID_FINISH object:connection];
    [connection connect];
    
    [UIApplication sharedApplication].networkActivityIndicatorVisible = YES;
}

- (void)didLoadStatus:(NSNotification *)notification {
    
    [UIApplication sharedApplication].networkActivityIndicatorVisible = NO;
    
    LoctouchAPIConnection* connection = (LoctouchAPIConnection*)[notification object];
    NSData* jsonData;
    jsonData = connection.responseData;
    
    if (connection.isFail || jsonData == nil) {
        NSLog(@"connection fail");
        return;
    }
    
    id jsonObject = [jsonData objectFromJSONData];
    
    if (![jsonObject isKindOfClass:[NSDictionary class]]) {
        NSLog(@"data is invalid.");
        return;
    }
    
    NSDictionary *member = (NSDictionary *)[(NSDictionary *)jsonObject  objectForKey:@"user"];
    NSString *displayName = [member objectForKey:@"display_name"];
    
    [[NSUserDefaults standardUserDefaults] setObject:displayName forKey:@"loctouch_display_name"];
    
    [self dismissModalViewControllerAnimated:YES];
}

- (NSString *)urlencode:(NSString *)string
{
    if (string == nil) {
        return nil;
    }
	NSString* encodedString = (NSString *)CFURLCreateStringByAddingPercentEscapes(NULL, (CFStringRef)string, NULL, (CFStringRef)@"!*'();:@&=+$,/?%#[]", kCFStringEncodingUTF8);
    [encodedString autorelease];
	return encodedString;
}

@end
