/*
 * Copyright 2011 livedoor Co.,Ltd.
 *
 * Licensed under the Apache License, Version 2.0.
 *
 */

#import "LoctouchAPIConnection.h"

@interface LoctouchAPIConnection()

@property (nonatomic, retain) NSURLConnection* connection;
- (NSString*)authHeader;

@end

@implementation LoctouchAPIConnection

@synthesize urlString, connection, responseData, isFail;

- (void)connect
{
    if (!self.urlString) return;
    NSLog(@"connect... %@", self.urlString);
    NSMutableURLRequest *request = [NSMutableURLRequest requestWithURL:[NSURL URLWithString:self.urlString]
                                                           cachePolicy:NSURLRequestReloadIgnoringLocalCacheData 
                                                       timeoutInterval:15.0];
    [request setValue:[self authHeader] forHTTPHeaderField:@"Authorization"];
	
	self.responseData = [NSMutableData data];
	self.connection = [NSURLConnection connectionWithRequest:request delegate:self];
}

- (NSString*)authHeader
{   
    NSString *accessToken = [[NSUserDefaults standardUserDefaults] stringForKey:@"loctouch_access_token"];
    return [NSString stringWithFormat:@"OAuth %@", accessToken];
}

- (void)cancel
{
	[self.connection cancel];
	self.connection = nil;
}

- (void)dealloc 
{
    self.urlString = nil;
	self.connection = nil;
	self.responseData = nil;
	[super dealloc];
}

#pragma mark -
#pragma mark URL Connection

- (void)connection:(NSURLConnection*)connection didReceiveResponse:(NSURLResponse*)response
{
    [self.responseData setLength:0];
}

- (void)connection:(NSURLConnection *)connection didReceiveData:(NSData *)data {
	[self.responseData appendData:data];
}

- (void)connectionDidFinishLoading:(NSURLConnection *)connection {
	self.connection = nil;    
    [[NSNotificationCenter defaultCenter] postNotificationName:LOCTOUCH_API_CONNECTION_DID_FINISH object:self];
}

- (void)connection:(NSURLConnection*)connection didFailWithError:(NSError*)error {	
	self.connection = nil;
    self.responseData = nil;
    
    self.isFail = YES;
    [[NSNotificationCenter defaultCenter] postNotificationName:LOCTOUCH_API_CONNECTION_DID_FINISH object:self];
}

@end
