/*
 * Copyright 2011 livedoor Co.,Ltd.
 *
 * Licensed under the Apache License, Version 2.0.
 *
 */

#import "RootViewController.h"
#import "LoctouchAPIConnection.h"
#import "JSONKit.h"

@interface RootViewController()

@property (nonatomic, retain) NSArray* itemArray;

- (void)loadTouches;
- (void)didLoadTouches:(NSNotification *)notification;
- (NSString *)dateFromUnixtime:(NSString *)unixtime;

@end

@implementation RootViewController

@synthesize itemArray;

- (void)viewDidLoad
{
    [super viewDidLoad];
    self.itemArray = [NSArray array];    
}

- (void)viewWillAppear:(BOOL)animated
{
    [super viewWillAppear:animated];
    
    NSString *displayName = [[NSUserDefaults standardUserDefaults] stringForKey:@"loctouch_display_name"];
    if (displayName != nil) {
        self.title = [NSString stringWithFormat:@"%@のタッチ", displayName];
    } else {      
        self.title = @"タッチ";
    }
}

- (void)viewDidAppear:(BOOL)animated
{
    [super viewDidAppear:animated];
    if ([self.itemArray count] == 0) {
        [self loadTouches];        
    }
}

- (void)dealloc
{
    self.itemArray = nil;
    [super dealloc];
}

#pragma mark UITableView

- (NSInteger)numberOfSectionsInTableView:(UITableView *)tableView
{
    return 1;
}

- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section
{
    return [self.itemArray count];
}

- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath
{
    static NSString *CellIdentifier = @"Cell";
    
    UITableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:CellIdentifier];
    if (cell == nil) {
        cell = [[[UITableViewCell alloc] initWithStyle:UITableViewCellStyleSubtitle reuseIdentifier:CellIdentifier] autorelease];
    }

    NSDictionary *touch = [self.itemArray objectAtIndex:indexPath.row];
    NSDictionary *spot = [touch objectForKey:@"spot"];
    
    cell.textLabel.text = [spot objectForKey:@"name"];
    cell.detailTextLabel.text = [self dateFromUnixtime:[touch objectForKey:@"time"]];
    
    return cell;
}

- (void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    NSDictionary *touch = [self.itemArray objectAtIndex:indexPath.row];
    NSString *link = [touch objectForKey:@"link"];
    
    [tableView deselectRowAtIndexPath:indexPath animated:YES];
    
    [[UIApplication sharedApplication] openURL:[NSURL URLWithString:link]];
}

#pragma mark API request

- (void)loadTouches {
    
    LoctouchAPIConnection* connection = [[[LoctouchAPIConnection alloc] init] autorelease];
    connection.urlString = @"https://api.loctouch.com/v1/users/@self/touches";
    
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(didLoadTouches:) name:LOCTOUCH_API_CONNECTION_DID_FINISH object:connection];
    [connection connect];
    
    [UIApplication sharedApplication].networkActivityIndicatorVisible = YES;
}

- (void)didLoadTouches:(NSNotification *)notification {
    
    [UIApplication sharedApplication].networkActivityIndicatorVisible = NO;
    
    LoctouchAPIConnection* connection = (LoctouchAPIConnection*)[notification object];
    NSData* jsonData;
    jsonData = connection.responseData;
    
    if (connection.isFail || jsonData == nil) {
        NSLog(@"connection fail");
        return;
    }
    
    id jsonObject = [jsonData objectFromJSONData];
    
    if (![jsonObject isKindOfClass:[NSDictionary class]]) {
        NSLog(@"data is invalid.");
        return;
    }
    
    self.itemArray = (NSArray *)[(NSDictionary *)jsonObject objectForKey:@"touches"];
    
    if ([self.itemArray count] > 0) {
        [self.tableView reloadData];
    }
}

- (NSString *)dateFromUnixtime:(NSString *)unixtime 
{      
    NSDateFormatter *outputFormatter = [[NSDateFormatter alloc] init];
    [outputFormatter setDateFormat:@"M月d日 H時mm分"];
    NSString* date = [outputFormatter stringFromDate:[NSDate dateWithTimeIntervalSince1970:[unixtime intValue]]];
    [outputFormatter release];
    return date;
}

@end
